@@ -35,9 +35,28 @@
 #include "gsm_pkexec.h"
 #include "cgroups.h"
 
-static AdwMessageDialog*renice_dialog = NULL;
+static AdwAlertDialog *renice_dialog = NULL;
 static gint new_nice_value = 0;
 
+static GtkWindow *
+get_active_window ()
+{
+  GListModel *toplevels = gtk_window_get_toplevels ();
+
+  guint n_toplevels = g_list_model_get_n_items (toplevels);
+  for (guint i = 0; i < n_toplevels; i++)
+    {
+      GtkWindow *window = GTK_WINDOW (g_list_model_get_item (toplevels, i));
+
+      if (gtk_window_is_active (window))
+        return window;
+    }
+
+  g_object_unref (toplevels);
+
+  return NULL;
+}
+
 static void
 kill_dialog_choose (GObject      *dialog,
                     GAsyncResult *res,
@@ -45,12 +64,12 @@ kill_dialog_choose (GObject      *dialog,
 {
   struct ProcActionArgs *kargs = static_cast<ProcActionArgs*>(data);
 
-  const gchar *res_id = adw_message_dialog_choose_finish (ADW_MESSAGE_DIALOG (dialog), res);
+  const gchar *res_id = adw_alert_dialog_choose_finish (ADW_ALERT_DIALOG (dialog), res);
 
-  if (g_str_equal (res_id, adw_message_dialog_get_close_response (ADW_MESSAGE_DIALOG (dialog))))
+  if (g_str_equal (res_id, adw_alert_dialog_get_close_response (ADW_ALERT_DIALOG (dialog))))
     return;
 
-  kill_process (kargs->app, kargs->arg_value);
+  kill_process (kargs->app, kargs->arg_value, -1);
 
   proctable_thaw (kargs->app);
   proctable_update (kargs->app);
@@ -59,11 +78,13 @@ kill_dialog_choose (GObject      *dialog,
 
 void
 procdialog_create_kill_dialog (GsmApplication *app,
-                               int             signal)
+                               int             signal,
+                               gint32          proc)
 {
-  AdwMessageDialog *kill_alert_dialog;
+  AdwAlertDialog *kill_alert_dialog;
   struct ProcActionArgs *kargs;
   gchar *primary, *secondary, *button_text;
+  GCancellable *cancellable;
 
   proctable_freeze (app);
   kargs = g_new (ProcActionArgs, 1);
@@ -71,12 +92,20 @@ procdialog_create_kill_dialog (GsmApplication *app,
   kargs->arg_value = signal;
   gint selected_count = gtk_tree_selection_count_selected_rows (app->selection);
 
-  if (selected_count == 1)
+  if (selected_count == 1 || proc != -1)
     {
       ProcInfo *selected_process = NULL;
-      // get the last selected row
-      gtk_tree_selection_selected_foreach (app->selection, get_last_selected,
-                                           &selected_process);
+
+      if (proc == -1)
+        {
+          // get the last selected row
+          gtk_tree_selection_selected_foreach (app->selection, get_last_selected,
+                                               &selected_process);
+        }
+      else
+        {
+          selected_process = app->processes.find (proc);
+        }
 
       std::string *process_name = &selected_process->name;
       std::string short_process_name = process_name->substr (0, process_name->find (" -"));
@@ -85,23 +114,20 @@ procdialog_create_kill_dialog (GsmApplication *app,
         {
           case SIGKILL:
             /*xgettext: primary alert message for killing single process*/
-            primary = g_strdup_printf (_("Are you sure you want to kill the selected process “%s” (PID: %u)?"),
-                                       short_process_name.c_str (),
-                                       selected_process->pid);
+            primary = g_strdup_printf (_("Force Stop %s?"),
+                                       short_process_name.c_str ());
             break;
 
           case SIGTERM:
             /*xgettext: primary alert message for ending single process*/
-            primary = g_strdup_printf (_("Are you sure you want to end the selected process “%s” (PID: %u)?"),
-                                       short_process_name.c_str (),
-                                       selected_process->pid);
+            primary = g_strdup_printf (_("End %s?"),
+                                       short_process_name.c_str ());
             break;
 
           default:   // SIGSTOP
             /*xgettext: primary alert message for stopping single process*/
-            primary = g_strdup_printf (_("Are you sure you want to stop the selected process “%s” (PID: %u)?"),
-                                       short_process_name.c_str (),
-                                       selected_process->pid);
+            primary = g_strdup_printf (_("Stop %s?"),
+                                       short_process_name.c_str ());
             break;
         }
     }
@@ -111,22 +137,22 @@ procdialog_create_kill_dialog (GsmApplication *app,
         {
           case SIGKILL:
             /*xgettext: primary alert message for killing multiple processes*/
-            primary = g_strdup_printf (ngettext ("Are you sure you want to kill the selected process?",
-                                                 "Are you sure you want to kill the %d selected processes?", selected_count),
+            primary = g_strdup_printf (ngettext ("Force Stop Selected Process?",
+                                                 "Force Stop %d Selected Processes?", selected_count),
                                        selected_count);
             break;
 
           case SIGTERM:
             /*xgettext: primary alert message for ending multiple processes*/
-            primary = g_strdup_printf (ngettext ("Are you sure you want to end the selected process?",
-                                                 "Are you sure you want to end the %d selected processes?", selected_count),
+            primary = g_strdup_printf (ngettext ("End Selected Process?",
+                                                 "End %d Selected Processes?", selected_count),
                                        selected_count);
             break;
 
           default:   // SIGSTOP
             /*xgettext: primary alert message for stopping multiple processes*/
-            primary = g_strdup_printf (ngettext ("Are you sure you want to stop the selected process?",
-                                                 "Are you sure you want to stop the %d selected processes?", selected_count),
+            primary = g_strdup_printf (ngettext ("Stop Selected Process?",
+                                                 "Stop %d Selected Processes?", selected_count),
                                        selected_count);
             break;
         }
@@ -136,44 +162,44 @@ procdialog_create_kill_dialog (GsmApplication *app,
     {
       case SIGKILL:
         /*xgettext: secondary alert message*/
-        secondary = _("Killing a process may destroy data, break the "
-                      "session or introduce a security risk. "
-                      "Only unresponsive processes should be killed.");
-        button_text = ngettext ("_Kill Process", "_Kill Processes", selected_count);
+        secondary = _("Force stopping processes can result in data "
+                      "loss, crashes, and system failures");
+        button_text = _("_Force Stop");
         break;
 
       case SIGTERM:
         /*xgettext: secondary alert message*/
-        secondary = _("Ending a process may destroy data, break the "
-                      "session or introduce a security risk. "
-                      "Only unresponsive processes should be ended.");
-        button_text = ngettext ("_End Process", "_End Processes", selected_count);
+        secondary = _("Ending processes can result in data loss, "
+                      "crashes, and system failures");
+        button_text = _("_End");
         break;
 
       default:   // SIGSTOP
         /*xgettext: secondary alert message*/
-        secondary = _("Stopping a process may destroy data, break the "
-                      "session or introduce a security risk. "
-                      "Only unresponsive processes should be stopped.");
-        button_text = ngettext ("_Stop Process", "_Stop Processes", selected_count);
+        secondary = _("Stopping processes can result in data loss, "
+                      "crashes, and system failures");
+        button_text = _("_Stop");
         break;
     }
 
-  kill_alert_dialog = ADW_MESSAGE_DIALOG (adw_message_dialog_new (GTK_WINDOW (app->main_window), primary, secondary));
+  kill_alert_dialog = ADW_ALERT_DIALOG (adw_alert_dialog_new (primary, secondary));
   g_free (primary);
 
-  adw_message_dialog_add_responses (ADW_MESSAGE_DIALOG (kill_alert_dialog),
-                                    "cancel", _("_Cancel"),
-                                    "apply", button_text,
-                                    NULL);
-  adw_message_dialog_set_default_response (ADW_MESSAGE_DIALOG (kill_alert_dialog), "cancel");
-  adw_message_dialog_set_close_response (ADW_MESSAGE_DIALOG (kill_alert_dialog), "cancel");
-  adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (kill_alert_dialog), "apply", ADW_RESPONSE_DESTRUCTIVE);
+  adw_alert_dialog_add_responses (ADW_ALERT_DIALOG (kill_alert_dialog),
+                                  "cancel", _("_Cancel"),
+                                  "apply", button_text,
+                                  NULL);
+  adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (kill_alert_dialog), "cancel");
+  adw_alert_dialog_set_close_response (ADW_ALERT_DIALOG (kill_alert_dialog), "cancel");
+  adw_alert_dialog_set_response_appearance (ADW_ALERT_DIALOG (kill_alert_dialog), "apply", ADW_RESPONSE_DESTRUCTIVE);
 
-  adw_message_dialog_choose (ADW_MESSAGE_DIALOG (kill_alert_dialog),
-                             NULL,
-                             kill_dialog_choose,
-                             kargs);
+  cancellable = g_cancellable_new ();
+
+  adw_alert_dialog_choose (ADW_ALERT_DIALOG (kill_alert_dialog),
+                           GTK_WIDGET (get_active_window ()),
+                           cancellable,
+                           kill_dialog_choose,
+                           kargs);
 }
 
 static void
@@ -191,7 +217,7 @@ renice_adjustment_value_changed (GtkAdjustment *adjustment,
 }
 
 static void
-renice_dialog_response (AdwMessageDialog*,
+renice_dialog_response (AdwAlertDialog*,
                         gchar   *response,
                         gpointer data)
 {
@@ -200,7 +226,6 @@ renice_dialog_response (AdwMessageDialog*,
   if (g_str_equal (response, "change"))
     renice (app, new_nice_value);
 
-  gtk_window_destroy (GTK_WINDOW (renice_dialog));
   renice_dialog = NULL;
 }
 
@@ -242,16 +267,15 @@ procdialog_create_renice_dialog (GsmApplication *app)
                     G_CALLBACK (renice_adjustment_value_changed),
                     priority_label);
 
-  renice_dialog = ADW_MESSAGE_DIALOG (gtk_builder_get_object (builder, "renice_dialog"));
-  gtk_window_set_transient_for (GTK_WINDOW (renice_dialog), GTK_WINDOW (app->main_window));
+  renice_dialog = ADW_ALERT_DIALOG (gtk_builder_get_object (builder, "renice_dialog"));
 
   if (selected_count == 1)
-    dialog_title = g_strdup_printf (_("Change Priority of Process “%s” (PID: %u)"),
+    dialog_title = g_strdup_printf (_("Change Priority of %s (PID %u)"),
                                     info->name.c_str (), info->pid);
   else
-    dialog_title = g_strdup_printf (ngettext ("Change Priority of the selected process", "Change Priority of %d selected processes", selected_count),
+    dialog_title = g_strdup_printf (ngettext ("Change Priority of the Selected Process", "Change Priority of %d Selected Processes", selected_count),
                                     selected_count);
-  adw_message_dialog_set_heading (ADW_MESSAGE_DIALOG (renice_dialog), dialog_title);
+  adw_alert_dialog_set_heading (renice_dialog, dialog_title);
   g_free (dialog_title);
 
   g_signal_connect (G_OBJECT (renice_dialog),
@@ -259,9 +283,9 @@ procdialog_create_renice_dialog (GsmApplication *app)
                     G_CALLBACK (renice_dialog_response),
                     app);
 
-  g_object_unref (G_OBJECT (builder));
+  adw_dialog_present (ADW_DIALOG (renice_dialog), GTK_WIDGET (app->main_window));
 
-  gtk_widget_set_visible (GTK_WIDGET (renice_dialog), TRUE);
+  g_object_unref (G_OBJECT (builder));
 }
 
 static char *
