@@ -103,7 +103,7 @@ cb_tree_button_pressed (GtkGestureClick*,
     gtk_tree_selection_select_path (selection, path);
   gtk_tree_path_free (path);
 
-  GdkRectangle rect = { x, y, 1, 1 };
+  GdkRectangle rect = { (gint)x, (gint)y, 1, 1 };
 
   gtk_popover_set_pointing_to (GTK_POPOVER (app->proc_popover_menu), &rect);
   gtk_popover_popup (GTK_POPOVER (app->proc_popover_menu));
@@ -133,7 +133,7 @@ cb_row_selected (GtkTreeSelection *selection,
 
   app->selection = selection;
 
-  gchar *button_text = ngettext ("_End Process", "_End Processes", selected_count);
+  gchar *button_text = ngettext ("_End Process…", "_End Processes…", selected_count);
 
   gtk_button_set_label (GTK_BUTTON (app->end_process_button), button_text);
 
@@ -341,7 +341,7 @@ proctable_new (GsmApplication * const app)
   GtkTreeViewColumn *column;
   GtkCellRenderer *cell_renderer;
   const gchar *titles[] = {
-    N_("Process Name"),
+    N_("Name"),
     N_("User"),
     N_("Status"),
     N_("Virtual Memory"),
@@ -349,7 +349,7 @@ proctable_new (GsmApplication * const app)
     N_("Writable Memory"),
     N_("Shared Memory"),
     N_("X Server Memory"),
-    /* xgettext:no-c-format */ N_("% CPU"),
+    /* xgettext:no-c-format */ N_("CPU"),
     N_("CPU Time"),
     N_("Started"),
     N_("Nice"),
@@ -366,10 +366,10 @@ proctable_new (GsmApplication * const app)
     for multi-seat environments. See http://en.wikipedia.org/wiki/Multiseat_configuration */
     N_("Seat"),
     N_("Owner"),
-    N_("Disk read total"),
-    N_("Disk write total"),
-    N_("Disk read"),
-    N_("Disk write"),
+    N_("Disk Read Total"),
+    N_("Disk Write Total"),
+    N_("Disk Read"),
+    N_("Disk Write"),
     N_("Priority"),
     NULL,
     "POINTER"
